@@ -5,8 +5,7 @@
  *   SPDX-License-Identifier: LGPL-2.0-or-later                            *
  ***************************************************************************/
 
-#ifndef UrlInserter_H
-#define UrlInserter_H
+#pragma once
 
 #include <QLineEdit>
 #include <QToolButton>
@@ -15,7 +14,6 @@
 
 class UrlInserter : public QWidget
 {
-    Q_OBJECT
 public:
     UrlInserter(const QUrl &startUrl, QWidget *parent);
     QLineEdit *lineEdit()
@@ -33,5 +31,3 @@ private:
     QUrl m_startUrl;
     bool m_replace;
 };
-
-#endif
