@@ -9,18 +9,11 @@
 #pragma once
 
 #include "katemdi.h"
+#include "kateprivate_export.h"
 #include "kateviewmanager.h"
 
-#include <ktexteditor/document.h>
 #include <ktexteditor/mainwindow.h>
-#include <ktexteditor/view.h>
 
-#include <KIO/UDSEntry>
-#include <KParts/Part>
-
-#include <QDragEnterEvent>
-#include <QDropEvent>
-#include <QEvent>
 #include <QHash>
 #include <QStackedLayout>
 #include <QUrl>
@@ -38,6 +31,7 @@ namespace KIO
 {
 class UDSEntry;
 typedef class QList<UDSEntry> UDSEntryList;
+class Job;
 }
 
 class KFileItem;
@@ -46,18 +40,20 @@ class KRecentFilesAction;
 class KateOutputView;
 class KateViewManager;
 class KateMwModOnHdDialog;
+class QDragEnterEvent;
+class QDropEvent;
+class QEvent;
 
 // Helper layout class to always provide minimum size
 class KateContainerStackedLayout : public QStackedLayout
 {
-    Q_OBJECT
 public:
     explicit KateContainerStackedLayout(QWidget *parent);
     QSize sizeHint() const override;
     QSize minimumSize() const override;
 };
 
-class KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBase
+class KATE_PRIVATE_EXPORT KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBase
 {
     Q_OBJECT
 
@@ -115,12 +111,12 @@ public:
     bool showModOnDiskPrompt(ModOnDiskMode mode);
 
 public:
-    /*reimp*/ void readProperties(const KConfigGroup &config) override;
-    /*reimp*/ void saveProperties(KConfigGroup &config) override
+    void readProperties(const KConfigGroup &config) override;
+    void saveProperties(KConfigGroup &config) override
     {
         saveProperties(config, true);
     }
-    /*reimp*/ void saveGlobalProperties(KConfig *sessionConfig) override;
+    void saveGlobalProperties(KConfig *sessionConfig) override;
 
     void saveProperties(KConfigGroup &config, bool includeViewConfig);
 
@@ -175,13 +171,13 @@ private:
     void dragEnterEvent(QDragEnterEvent *) override;
     void dropEvent(QDropEvent *) override;
 
-public Q_SLOTS:
-    void slotFileClose();
+public:
     void slotFileQuit();
     void queueModifiedOnDisc(KTextEditor::Document *doc);
 
     void slotFocusPrevTab();
     void slotFocusNextTab();
+    void slotSwitchToTab(const int i);
 
     /**
      * Show quick open
@@ -206,6 +202,11 @@ public Q_SLOTS:
      * or internal signal connections
      */
 private Q_SLOTS:
+    // Connected to KTextEditor::View dropEventPass private signal so marked as Q_SLOT.
+    // TODO make the api public as it is apparently needed
+    void slotDropEvent(QDropEvent *);
+
+private:
     void slotConfigure();
 
     void slotOpenWithMenuAction(QAction *a);
@@ -213,9 +214,7 @@ private Q_SLOTS:
     void slotEditToolbars();
     void slotNewToolbarConfig();
     void slotUpdateActionsNeedingUrl();
-    void slotOpenDocument(const QUrl &);
 
-    void slotDropEvent(QDropEvent *);
     void editKeys();
     void mSlotFixOpenWithMenu();
     static void reloadXmlGui();
@@ -233,7 +232,7 @@ private Q_SLOTS:
 
     void onApplicationStateChanged(Qt::ApplicationState);
 
-private Q_SLOTS:
+private:
 #if KATE_ALLOW_MENU_BAR_HIDE
     void toggleShowMenuBar(bool showMessage = true);
     void ensureHamburgerBarSize();
@@ -381,10 +380,7 @@ public Q_SLOTS:
      * \param document the document
      * \return activated view of this document
      */
-    KTextEditor::View *activateView(KTextEditor::Document *document)
-    {
-        return viewManager()->activateView(document);
-    }
+    KTextEditor::View *activateView(KTextEditor::Document *document);
 
     /**
      * Open the document \p url with the given \p encoding.
@@ -610,7 +606,7 @@ public Q_SLOTS:
 
     void addPositionToHistory(const QUrl &url, KTextEditor::Cursor c);
 
-private Q_SLOTS:
+private:
     void slotUpdateBottomViewBar();
     void slotDocumentCloseAll();
     void slotDocumentCloseOther();
@@ -734,13 +730,19 @@ public:
      * The available actions for the mouse back button, used as indexing
      * for the comboboxes of the config window
      */
-    enum MouseBackButtonAction { PreviousTab = 0, HistoryBack };
+    enum MouseBackButtonAction {
+        PreviousTab = 0,
+        HistoryBack
+    };
 
     /**
      * The available actions for the mouse forward button, used as indexing
      * for the comboboxes of the config window
      */
-    enum MouseForwardButtonAction { NextTab = 0, HistoryForward };
+    enum MouseForwardButtonAction {
+        NextTab = 0,
+        HistoryForward
+    };
 
 private:
     MouseBackButtonAction m_mouseButtonBackAction = PreviousTab;
@@ -766,12 +768,11 @@ public:
         }
     }
 
+    void slotWindowActivated();
+
 private:
     static KateMwModOnHdDialog *s_modOnHdDialog;
 
-public Q_SLOTS:
-    void slotWindowActivated();
-
 protected:
     bool event(QEvent *e) override;
     void mousePressEvent(QMouseEvent *e) override;
