@@ -10,6 +10,7 @@
 #include "kateapp.h"
 #include "katemainwindow.h"
 
+#include <KLocalizedString>
 #include <KTextEditor/Document>
 #include <KTextEditor/View>
 
@@ -85,6 +86,7 @@ void KateQuickOpenModel::refresh(KateMainWindow *mainWindow)
     const QStringList projectDocs = projectView
         ? (m_listMode == CurrentProject ? projectView->property("projectFiles") : projectView->property("allProjectsFiles")).toStringList()
         : QStringList();
+    const auto projects = projectView ? projectView->property("allProjects").toMap() : QVariantMap();
     const QString projectBase = [projectView]() -> QString {
         if (!projectView) {
             return QString();
@@ -153,9 +155,14 @@ void KateQuickOpenModel::refresh(KateMainWindow *mainWindow)
         allDocuments.push_back({std::move(fileName), filePath, nullptr, -1});
     }
 
+    // Add projects to the docunents list, and the filepath is their base directory
+    if (projects.count() > 1) {
+        for (const auto &project : projects.asKeyValueRange()) {
+            allDocuments.push_back({i18n("Project: %1", project.second.toString()), project.first, nullptr, -1});
+        }
+    }
+
     beginResetModel();
     m_modelEntries = std::move(allDocuments);
     endResetModel();
 }
-
-#include "moc_katequickopenmodel.cpp"
