@@ -4,8 +4,11 @@
 */
 #include "KateTextHintManager.h"
 
+#include "hintview.h"
 #include "tooltip.h"
+#include <kateapp.h>
 
+#include <KSharedConfig>
 #include <KTextEditor/MainWindow>
 #include <KTextEditor/TextHintInterface>
 #include <KTextEditor/View>
@@ -59,7 +62,7 @@ public:
 
     virtual QString textHint(KTextEditor::View *view, const KTextEditor::Cursor &position) override
     {
-        m_mgr->ontextHintRequested(view, position);
+        m_mgr->ontextHintRequested(view, position, KateTextHintManager::Requestor::HintProvider);
         return {};
     }
 };
@@ -67,15 +70,31 @@ public:
 KateTextHintManager::KateTextHintManager(KTextEditor::MainWindow *mainWindow)
     : QObject(mainWindow)
     , m_provider(new KTETextHintProvider(this))
+    , m_hintView(nullptr)
 {
     connect(mainWindow, &KTextEditor::MainWindow::viewChanged, this, [this](KTextEditor::View *v) {
         m_provider->setView(v);
     });
+
+    const auto updateConfig = [this, mainWindow] {
+        KConfigGroup cgGeneral = KConfigGroup(KSharedConfig::openConfig(), QStringLiteral("General"));
+        const auto hintViewEnabled = cgGeneral.readEntry("Enable Context ToolView", false);
+        if (hintViewEnabled && !m_hintView) {
+            m_hintView = new KateTextHintView(mainWindow, this);
+        } else if (!hintViewEnabled && m_hintView) {
+            delete m_hintView;
+            m_hintView = nullptr;
+        }
+    };
+
+    connect(KateApp::self(), &KateApp::configurationChanged, this, updateConfig);
+    updateConfig();
 }
 
 KateTextHintManager::~KateTextHintManager()
 {
     m_provider->setView(nullptr);
+    delete m_hintView;
     delete m_provider;
 }
 
@@ -89,40 +108,57 @@ void KateTextHintManager::registerProvider(KateTextHintProvider *provider)
                 m_providers.erase(it);
             }
         });
-        connect(provider, &KateTextHintProvider::textHintAvailable, this, &KateTextHintManager::onTextHintAvailable);
-        connect(provider, &KateTextHintProvider::showTextHint, this, &KateTextHintManager::onShowTextHint);
+
+        const auto slot = [provider, this](bool forced) {
+            return [this, provider, forced](const QString &hint, TextHintMarkupKind kind, KTextEditor::Cursor pos) {
+                const auto instanceId = reinterpret_cast<std::uintptr_t>(provider);
+
+                if (m_lastRequestor == Requestor::CursorChange && m_hintView) {
+                    m_hintView->update(instanceId, hint, kind, m_provider->view());
+                    return;
+                }
+
+                showTextHint(instanceId, hint, kind, pos, forced);
+            };
+        };
+        connect(provider, &KateTextHintProvider::textHintAvailable, this, slot(false));
+        connect(provider, &KateTextHintProvider::showTextHint, this, slot(true));
     }
 }
 
-void KateTextHintManager::ontextHintRequested(KTextEditor::View *v, KTextEditor::Cursor c)
+void KateTextHintManager::ontextHintRequested(KTextEditor::View *v, KTextEditor::Cursor c, Requestor hintSource)
 {
-    for (auto provider : m_providers) {
-        Q_EMIT provider->textHintRequested(v, c);
-    }
-}
-
-void KateTextHintManager::showTextHint(const QString &hint, TextHintMarkupKind kind, KTextEditor::Cursor pos, bool force)
-{
-    if (QStringView(hint).trimmed().isEmpty() || !pos.isValid()) {
+    auto wordRange = v->document()->wordRangeAt(c);
+    // avoid requesting if the range is same
+    if (wordRange == m_lastRange) {
         return;
     }
+    m_lastRange = wordRange;
+    for (const auto &provider : m_providers) {
+        Q_EMIT provider->textHintRequested(v, c);
+    }
+    m_lastRequestor = hintSource;
+}
+
+void KateTextHintManager::showTextHint(size_t instanceId, const QString &hint, TextHintMarkupKind kind, KTextEditor::Cursor pos, bool force)
+{
+    if (!pos.isValid()) {
+        return;
+    }
+
     auto view = m_provider->view();
     if (!view) {
         return;
     }
 
     QPoint p = view->cursorToCoordinate(pos);
-    KateTooltip::show(hint, kind, view->mapToGlobal(p), view, force);
-}
-
-void KateTextHintManager::onTextHintAvailable(const QString &hint, TextHintMarkupKind kind, KTextEditor::Cursor pos)
-{
-    showTextHint(hint, kind, pos, false);
-}
-
-void KateTextHintManager::onShowTextHint(const QString &hint, TextHintMarkupKind kind, KTextEditor::Cursor pos)
-{
-    showTextHint(hint, kind, pos, true);
+    auto tooltip = KateTooltip::show(instanceId, hint, kind, view->mapToGlobal(p), view, force, m_lastRange);
+    if (tooltip) {
+        // unset the range if the tooltip is gone
+        connect(tooltip, &QObject::destroyed, this, [this] {
+            m_lastRange = KTextEditor::Range::invalid();
+        });
+    }
 }
 
 #include "moc_KateTextHintManager.cpp"
